@@ -65,7 +65,7 @@ extern OOP _gst_vmsg_send (OOP receiver,
 extern OOP _gst_str_msg_send (OOP receiver, const char * sel, ...);
 
 /* See manual; basically it takes care of the conversion from C to
-   Smalltalk data types.  */
+   Smalltalk data types. */
 extern void _gst_msg_sendf (PTR resultPtr, const char * fmt, ...);
 
 /* Evaluate the Smalltalk code in STR and return the result as an OOP.
@@ -93,13 +93,13 @@ extern void _gst_unregister_oop (OOP oop);
    The two parameters, FIRST and LAST, point to two variables
    containing respectively the base and the top of the array: the
    double indirection allows one to move the array freely in memory,
-   for example using realloc.  */
+   for example using realloc. */
 extern void _gst_register_oop_array (OOP **first, OOP **last);
 
 /* Unregister the given array of OOPs from the root set.  FIRST points
    to a variables containing the base of the array: the double
    indirection allows one to move the array freely in memory, for
-   example using realloc.  */
+   example using realloc. */
 extern void _gst_unregister_oop_array (OOP **first);
 
 /* Allocates an OOP for a newly created instance of the class whose
@@ -110,7 +110,7 @@ extern void _gst_unregister_oop_array (OOP **first);
 
    The second parameter is used only if the class is an indexable one,
    otherwise it is discarded: it contains the number of indexed
-   instance variables in the object that is going to be created.  */
+   instance variables in the object that is going to be created. */
 extern OOP _gst_object_alloc (OOP class_oop,
 			      int size);
 
@@ -131,7 +131,6 @@ extern OOP _gst_symbol_to_oop (const char *str);
 extern OOP _gst_c_object_to_oop (PTR co);
 extern OOP _gst_type_name_to_oop (const char *name);
 extern void _gst_set_c_object (OOP oop, PTR co);
-extern OOP _gst_long_double_to_oop (long double f);
 
 /* Convert Smalltalk datatypes to C data types */
 extern long _gst_oop_to_c (OOP oop);	/* sometimes answers a PTR */
@@ -143,14 +142,13 @@ extern char _gst_oop_to_char (OOP oop);
 extern char *_gst_oop_to_string (OOP oop);
 extern char *_gst_oop_to_byte_array (OOP oop);
 extern PTR _gst_oop_to_cobject (OOP oop);
-extern long double _gst_oop_to_long_double (OOP oop);
 
 /* Marks/copies the registered OOPs (they are part of the rootset by
    definition) */
 extern void _gst_mark_registered_oops (void);
 extern void _gst_copy_registered_oops (void);
 
-/* Initializes the registry of OOPs which some C code is holding.  */
+/* Initializes the registry of OOPs which some C code is holding. */
 extern void _gst_init_oopregistry (void);
 
 /* Initializes the VMProxy.  */
