@@ -699,6 +699,16 @@ push_smalltalk_obj (OOP oop,
 	  u.intVal = TO_C_INT (oop);
 	  push_obj (&u, CPARAM_INT);
 	}
+      else if (cType == CDATA_DOUBLE || cType == CDATA_UNKNOWN)
+	{
+	  u.doubleVal = (double) TO_C_LONG (oop);
+	  push_obj (&u, CPARAM_DOUBLE);
+	}
+      else if (cType == CDATA_FLOAT)
+	{
+	  u.floatVal = (float) TO_C_LONG (oop);
+	  push_obj (&u, CPARAM_FLOAT);
+	}
       else
 	bad_type (class, cType);
     }
