@@ -1068,16 +1068,15 @@ compile_block (tree_node blockExpr)
   argCount = _gst_declare_block_arguments (blockExpr->v_block.arguments);
   tempCount = _gst_declare_temporaries (blockExpr->v_block.temporaries);
   compile_statements (blockExpr->v_block.statements, true);
-  _gst_pop_old_scope ();
 
   stack_depth = GET_STACK_DEPTH ();
   blockByteCodes = _gst_get_bytecodes ();
 
   blockClosureOOP =
-    make_block_closure (argCount, tempCount, blockByteCodes, stack_depth);
-  blockClosure = (gst_block_closure) OOP_TO_OBJ (blockClosureOOP);
-  block = (gst_compiled_block) OOP_TO_OBJ (blockClosure->block);
+    make_block_closure (_gst_get_arg_count (), _gst_get_temp_count (),
+			blockByteCodes, stack_depth);
 
+  _gst_pop_old_scope ();
   _gst_restore_bytecode_array (current_bytecodes);
 
   /* emit standard byte sequence to invoke a block: 
@@ -1086,6 +1085,8 @@ compile_block (tree_node blockExpr)
      blockCopy send -> may not be there at all when optimizing */
   INCR_STACK_DEPTH ();
   compile_push_literal (add_literal (blockClosureOOP));
+  blockClosure = (gst_block_closure) OOP_TO_OBJ (blockClosureOOP);
+  block = (gst_compiled_block) OOP_TO_OBJ (blockClosure->block);
   switch (block->header.clean)
     {
     case 0:
@@ -2840,7 +2841,6 @@ file_segment_new (void)
   OOP fileName, stringContents, fileSegmentOOP;
   gst_file_segment fileSegment;
   int startPos;
-  char *s;
   inc_ptr incPtr;
 
   switch (_gst_get_cur_stream_type ())
@@ -2850,35 +2850,21 @@ file_segment_new (void)
       return (_gst_nil_oop);
 
     case STREAM_FILE:
-      if (_gst_is_kernel_file ())
-	{
-	  incPtr = INC_SAVE_POINTER ();
-	  fileName = _gst_get_cur_file_name ();
-	  INC_ADD_OOP (fileName);
+      incPtr = INC_SAVE_POINTER ();
+      fileName = _gst_get_cur_file_name ();
+      INC_ADD_OOP (fileName);
 
-	  fileSegment = (gst_file_segment) new_instance (_gst_file_segment_class,
-							 &fileSegmentOOP);
+      fileSegment = (gst_file_segment) new_instance (_gst_file_segment_class,
+    						 &fileSegmentOOP);
 
-	  fileSegment->fileName = fileName;
-	  startPos = _gst_get_method_start_pos ();
-	  fileSegment->startPos = FROM_INT (startPos);
-	  fileSegment->length =
-	    FROM_INT (_gst_get_cur_file_pos () - startPos - 1);
+      fileSegment->fileName = fileName;
+      startPos = _gst_get_method_start_pos ();
+      fileSegment->startPos = FROM_INT (startPos);
+      fileSegment->length =
+        FROM_INT (_gst_get_cur_file_pos () - startPos - 1);
 
-	  INC_RESTORE_POINTER (incPtr);
-	  return (fileSegmentOOP);
-	}
-      else
-	{
-	  /* Return a string instance containing method source if the
-	     source was derived from a file loaded outside the kernel
-	     directory- brd */
-	  stringContents = _gst_string_new (s =
-					    _gst_get_method_source_from_cur_file
-					    ());
-	  xfree (s);
-	  return (stringContents);
-	}
+      INC_RESTORE_POINTER (incPtr);
+      return (fileSegmentOOP);
 
     case STREAM_STRING:
       stringContents = _gst_get_cur_string ();
