@@ -507,9 +507,10 @@ static const class_definition class_info[] = {
    "True", "truthValue", NULL, NULL },
 
   {&_gst_processor_scheduler_class, &_gst_object_class,
-   true, false, false, 4,
+   true, false, false, 6,
    "ProcessorScheduler",
-   "processLists activeProcess idleTasks processTimeslice", NULL, NULL },
+   "processLists activeProcess idleTasks processTimeslice gcSemaphore gcArray",
+   NULL, NULL },
 
   {&_gst_delay_class, &_gst_object_class,
    true, false, false, 2,
@@ -863,7 +864,8 @@ init_smalltalk_dictionary (void)
   _gst_init_symbols ();
 
   /* Add subspaces */
-  add_smalltalk ("CSymbols", _gst_dictionary_new (32));
+  add_smalltalk ("CSymbols",
+    namespace_new (32, "CSymbols", _gst_smalltalk_dictionary));
 
   add_smalltalk ("Undeclared",
     namespace_new (32, "Undeclared", _gst_nil_oop));
@@ -1135,7 +1137,7 @@ _gst_init_dictionary_on_image_load (long numOOPs)
 
   for (oop = _gst_mem.ot_base; oop < &_gst_mem.ot[numOOPs]; oop++)
     {
-      if (!IS_OOP_VALID (oop))
+      if (!IS_OOP_VALID_GC (oop))
 	continue;
 
       if UNCOMMON (OOP_CLASS (oop) == _gst_c_func_descriptor_class)
