@@ -65,7 +65,7 @@ typedef struct gst_dictionary
   OOP tally;			/* really, an int */
 
   /* Other, indexable fields that are the associations for this
-     dictionary.  */
+     dictionary. */
 }
  *gst_dictionary;
 
@@ -77,7 +77,7 @@ typedef struct gst_binding_dictionary
   OOP assoc[1];
 
   /* Other, indexable fields that are the associations for this
-     dictionary.  */
+     dictionary. */
 }
  *gst_binding_dictionary;
 
@@ -91,7 +91,7 @@ typedef struct gst_namespace
   OOP assoc[1];
 
   /* Other, indexable fields that are the associations for this
-     dictionary.  */
+     dictionary. */
 }
  *gst_namespace;
 
@@ -99,7 +99,9 @@ typedef struct gst_identity_dictionary
 {
   OBJ_HEADER;
   OOP tally;			/* really, an int */
-  OOP keys[1];			/* variable sized array of OOPS (keys/values) */
+  OOP values;			/* an gst_array */
+  OOP keys[1];			/* variable sized array of OOPS
+				   (symbols) */
 }
  *gst_identity_dictionary;
 
@@ -109,7 +111,7 @@ typedef struct gst_identity_dictionary
   OOP		superclass; \
   OOP		subClasses; \
   OOP		methodDictionary; \
-  intptr_t	instanceSpec; \
+  long		instanceSpec; \
   OOP		instanceVariables
 
 typedef struct gst_behavior
@@ -288,53 +290,53 @@ extern OOP _gst_object_class, _gst_magnitude_class, _gst_char_class,
   _gst_file_segment_class, _gst_c_object_type_ctype, _gst_processor_oop;
 
 /* Creates a new instance of the Dictionary class with room for SIZE
-   items.  */
+   items. */
 extern OOP _gst_dictionary_new (int size);
 
 /* Creates a new instance of the BindingDictionary class with room for SIZE
    items.  The object has the ENVIRONMENTOOP environment (which for
-   dictionary of class variables is the class that hosts the dictionary).  */
+   dictionary of class variables is the class that hosts the dictionary). */
 extern OOP _gst_binding_dictionary_new (int size,
 			        	OOP environmentOOP);
 
 /* Gets the method dictionary associated with CLASS_OOP, and returns
    it.  If the methodDictionary associated with CLASS_OOP is nil, one
-   is created and installed into that class.  */
+   is created and installed into that class. */
 extern OOP _gst_valid_class_method_dictionary (OOP class_oop) ATTRIBUTE_PURE;
 
 /* This returns the dictionary of class variables for CLASS_OOP */
 extern OOP _gst_class_variable_dictionary (OOP class_oop) ATTRIBUTE_PURE;
 
 /* This finds the key SYMBOL into the dictionary POOLOOP and, if any,
-   in all of its super-namespaces.  */
+   in all of its super-namespaces. */
 extern OOP _gst_find_shared_pool_variable (OOP poolOOP,
 					   OOP symbol) ATTRIBUTE_PURE;
 
 /* Adds the Association in ASSOCIATIONOOP to the Dictionary (or a
-   subclass sharing the same representation) DICTIONARYOOP.  */
+   subclass sharing the same representation) DICTIONARYOOP. */
 extern OOP _gst_dictionary_add (OOP dictionaryOOP,
 				OOP associationOOP);
 
 /* Creates a String object starting from the NUL-terminated string
-   S.  */
+   S. */
 extern OOP _gst_string_new (const char *s);
 
 /* Look in the Smalltalk dictionary for a class whose name is in the
-   Symbol CLASSNAMEOOP.  */
+   Symbol CLASSNAMEOOP. */
 extern OOP _gst_find_class (OOP classNameOOP) ATTRIBUTE_PURE;
 
 /* Look for an implementation of SELECTOR (a Symbol) into CLASS_OOP's
-   method dictionary or in the method dictionary of a superclass.  */
+   method dictionary or in the method dictionary of a superclass. */
 extern OOP _gst_find_class_method (OOP class_oop,
 				   OOP selector) ATTRIBUTE_PURE;
 
 /* Create a new Message object for the given SELECTOR (a Symbol) and
-   Array of arguments.  */
+   Array of arguments. */
 extern OOP _gst_message_new_args (OOP selectorOOP,
 				  OOP argsArray);
 
 /* Create a new DirectedMessage object for the given RECEIVER,
-   SELECTOR (a Symbol) and Array of arguments.  */
+   SELECTOR (a Symbol) and Array of arguments. */
 extern OOP _gst_directed_message_new_args (OOP receiverOOP,
 					   OOP selectorOOP,
 					   OOP argsArray);
@@ -346,45 +348,45 @@ extern OOP _gst_get_class_symbol (OOP class_oop) ATTRIBUTE_PURE;
    of OOP.  Builtin OOPs and integers are returned unchanged,
    while for other objects this is a "shallow copy"; all the
    instance variables in the new object are the exact same ones
-   that are in the original object.  */
+   that are in the original object. */
 extern OOP _gst_object_copy (OOP oop);
 
 /* Returns the array of the names of the instance variables of
-   CLASS_OOP (a Smalltalk Class).  */
+   CLASS_OOP (a Smalltalk Class). */
 extern OOP _gst_instance_variable_array (OOP class_oop) ATTRIBUTE_PURE;
 
 /* Returns the array of the names of the pool dictionaries of
-   CLASS_OOP (a Smalltalk Class).  */
+   CLASS_OOP (a Smalltalk Class). */
 extern OOP _gst_shared_pool_dictionary (OOP class_oop) ATTRIBUTE_PURE;
 
 /* Creates a new CObject pointing to cObjPtr, extracting the name of
-   the class to be instantiated from the CType, TYPEOOP.  */
+   the class to be instantiated from the CType, TYPEOOP. */
 extern OOP _gst_c_object_new_typed (PTR cObjPtr,
 				    OOP typeOOP);
 
 /* Allocates a new CObject by malloc-ing SIZE bytes; CLASS_OOP is the
-   class to be instantiated.  */
+   class to be instantiated. */
 extern OOP _gst_alloc_cobject (OOP class_oop,
-			       size_t size);
+			       long unsigned int size);
 
 /* Creates a new CType that when passed to _gst_c_object_new_typed
-   creates an instance of COBJECTSUBCLASSOOP.  */
+   creates an instance of COBJECTSUBCLASSOOP. */
 extern OOP _gst_c_type_new (OOP cObjectSubclassOOP);
 
-/* Creates a new String with LEN indexed instance variables.  */
-extern OOP _gst_new_string (size_t len);
+/* Creates a new String with LEN indexed instance variables. */
+extern OOP _gst_new_string (int len);
 
-/* Creates a new ByteArray containing LEN bytes starting at BYTES.  */
+/* Creates a new ByteArray containing LEN bytes starting at BYTES. */
 extern OOP _gst_byte_array_new (const gst_uchar * bytes,
-				size_t len);
+				int len);
 
-/* Creates a new String containing LEN characters starting at S.  */
+/* Creates a new String containing LEN characters starting at S. */
 extern OOP _gst_counted_string_new (const char *s,
-				    size_t len);
+				    int len);
 
 /* Adds the key KEYOOP, associated with VALUEOOP, to the
    IdentityDictionary (or a subclass sharing the same representation)
-   IDENTITYDICTIONARYOOP.  */
+   IDENTITYDICTIONARYOOP. */
 extern OOP _gst_identity_dictionary_at_put (OOP identityDictionaryOOP,
 					    OOP keyOOP,
 					    OOP valueOOP);
@@ -392,39 +394,39 @@ extern OOP _gst_identity_dictionary_at_put (OOP identityDictionaryOOP,
 /* Called when a dictionary becomes full, this routine replaces the
    dictionary instance that DICTIONARYOOP is pointing to with a new,
    larger dictionary, and returns this new dictionary (the object
-   pointer, not the OOP).  */
+   pointer, not the OOP). */
 extern mst_Object _gst_grow_dictionary (OOP dictionaryOOP);
 
 /* Called when an IdentityDictionary becomes full, this routine
    replaces the IdentityDictionary instance that IDENTITYDICTIONARYOOP
    is pointing to with a new, larger dictionary, and returns this new
-   dictionary (the object pointer, not the OOP).  */
+   dictionary (the object pointer, not the OOP). */
 extern gst_identity_dictionary _gst_grow_identity_dictionary (OOP identityDictionaryOOP);
 
 /* Allocates and returns a new C (ASCIZ) string that has the same
    contents as STRINGOOP.  Even if there are embedded NULs, the
-   allocated area has always a size of "stringOOP size + 1" bytes.  */
+   allocated area has always a size of "stringOOP size + 1" bytes. */
 extern char *_gst_to_cstring (OOP stringOOP);
 
 /* Allocates and returns a new memory block that has the same contents
    as BYTEARRAYOOP.  Even if there are embedded NULs, the allocated
-   area has always a size of "byteArrayOOP size" bytes.  */
+   area has always a size of "byteArrayOOP size" bytes. */
 extern gst_uchar *_gst_to_byte_array (OOP byteArrayOOP);
 
 /* Creates the kernel classes of the Smalltalk system.  Operates in two
    passes: pass1 creates the class objects, but they're not completely
    initialized.  pass2 finishes the initialization process.  The garbage
-   collector can NOT run during this time.  */
+   collector can NOT run during this time. */
 extern void _gst_init_dictionary (void);
 
 /* Copies the first bytes of S into STRINGOOP (as many bytes as the
-   OOP can hold).  */
+   OOP can hold). */
 extern void _gst_set_oopstring (OOP stringOOP,
 				const char *s);
 
 /* Set the instance variables of the FileStream object,
    FILESTREAMOOP.  If BUFFERED is true, the variables
-   inherited by Streams are set to a 1024-bytes String.  */
+   inherited by Streams are set to a 1024-bytes String. */
 extern void _gst_set_file_stream_file (OOP fileStreamOOP,
 				       int fd,
 				       OOP fileNameOOP,
@@ -433,20 +435,20 @@ extern void _gst_set_file_stream_file (OOP fileStreamOOP,
 				       mst_Boolean buffered);
 
 /* Copies the first bytes of BYTES into BYTEARRAYOOP (as many bytes as
-   the OOP can hold).  */
+   the OOP can hold). */
 extern void _gst_set_oop_bytes (OOP byteArrayOOP,
 				gst_uchar * bytes);
 
-/* Frees the memory pointed to by the CObject, COBJOOP.  */
+/* Frees the memory pointed to by the CObject, COBJOOP. */
 extern void _gst_free_cobject (OOP cObjOOP);
 
 /* Loads the contents of the global variable from the Smalltalk
    dictionary after NUMOOPS objects have been loaded from an
-   image.  */
-extern mst_Boolean _gst_init_dictionary_on_image_load (size_t numOOPs);
+   image. */
+extern mst_Boolean _gst_init_dictionary_on_image_load (long numOOPs);
 
 /* Transforms a primitive name into a primitive index, looking up
-   the VMPrimitives dictionary.  */
+   the VMPrimitives dictionary. */
 extern int _gst_resolve_primitive_name (char *name);
 
 #endif /* GST_DICT_H */
