@@ -183,6 +183,8 @@ typedef struct gst_processor_scheduler
   OOP activeProcess;
   OOP idleTasks;
   OOP processTimeslice;
+  OOP gcSemaphore;
+  OOP gcArray;
 }
  *gst_processor_scheduler;
 
