@@ -292,7 +292,7 @@ make_oop_table_to_be_saved (void)
 
   for (oop = _gst_mem.ot; oop < &_gst_mem.ot[_gst_mem.ot_size];
        oop++)
-    if (IS_OOP_VALID (oop))
+    if (IS_OOP_VALID_GC (oop))
       num_used_oops = OOP_INDEX (oop) + 1;
 
   _gst_mem.num_free_oops = _gst_mem.ot_size - num_used_oops;
@@ -307,7 +307,7 @@ make_oop_table_to_be_saved (void)
 
   for (i = 0, oop = _gst_mem.ot; i < num_used_oops; oop++, i++)
     {
-      if (IS_OOP_VALID (oop))
+      if (IS_OOP_VALID_GC (oop))
 	{
 	  int numPointers;
           myOOPTable[i].flags = oop->flags;
@@ -336,7 +336,7 @@ save_all_objects (int imageFd)
 
   for (oop = _gst_mem.ot; oop < &_gst_mem.ot[num_used_oops];
        oop++)
-    if (IS_OOP_VALID (oop))
+    if (IS_OOP_VALID_GC (oop))
       save_object (imageFd, oop);
 }
 
@@ -646,7 +646,7 @@ restore_all_pointer_slots ()
 
   for (oop = _gst_mem.ot; oop < &_gst_mem.ot[num_used_oops];
        oop++)
-    if (IS_OOP_VALID (oop))
+    if (IS_OOP_VALID_GC (oop))
       restore_oop_pointer_slots (oop);
 }
 
