@@ -87,7 +87,7 @@ OOP _gst_and_colon_symbol, _gst_at_colon_put_colon_symbol,
   _gst_not_equal_symbol, _gst_not_same_object_symbol,
   _gst_or_colon_symbol, _gst_plus_symbol, _gst_remainder_symbol,
   _gst_same_object_symbol, _gst_size_symbol, _gst_this_context_symbol,
-  _gst_mourn_symbol, _gst_times_symbol,
+  _gst_times_symbol,
   _gst_to_colon_do_colon_symbol, _gst_times_repeat_colon_symbol,
   _gst_to_colon_by_colon_do_colon_symbol,
   _gst_value_colon_symbol, _gst_value_colon_value_colon_symbol,
@@ -222,7 +222,6 @@ static const symbol_info sym_info[] = {
   {&_gst_long_symbol, "long"},
   {&_gst_ulong_symbol, "uLong"},
   {&_gst_minus_symbol, "-"},
-  {&_gst_mourn_symbol, "mourn"},
   {&_gst_must_be_boolean_symbol, "mustBeBoolean"},
   {&_gst_new_colon_symbol, "new:"},
   {&_gst_new_symbol, "new"},
