@@ -98,7 +98,7 @@ typedef unsigned long	_ul;
 #define _MASK(N)	((unsigned)((1<<(N)))-1)
 #define _siP(N,I)	(!((((unsigned)(I))^(((unsigned)(I))<<1))&~_MASK(N)))
 #define _uiP(N,I)	(!(((unsigned)(I))&~_MASK(N)))
-#define _suiP(N,I)	(_siP(N,I) | uiP(N,I))
+#define _suiP(N,I)	(_siP(N,I) | _uiP(N,I))
 
 #ifndef _ASM_SAFETY
 #define _ck_s(W,I)	(_UL(I) & _MASK(W))
