@@ -1,7 +1,7 @@
 /*  -*- Mode: C -*-  */
 
 /* stream.c ---  customizable stream routines
- * Copyright (C) 1998, 1999, 2000, 2002 Gary V. Vaughan
+ * Copyright (C) 1998, 1999, 2000, 2002, 2003 Gary V. Vaughan
  * Originally by Gary V. Vaughan, 1998
  * This file is part of Snprintfv
  *
@@ -75,11 +75,7 @@ stream_not_writable (int ch, STREAM *stream)
  * The address of the newly allocated and initialised stream is returned.
  **/
 STREAM *
-stream_new (dets, limit, get_func, put_func)
-     snv_pointer dets;
-     unsigned long limit;
-     StreamGet get_func;
-     StreamPut put_func;
+stream_new (snv_pointer dets, unsigned long limit, StreamGet get_func, StreamPut put_func)
 {
   STREAM *new = snv_new (STREAM, 1);
 
@@ -104,8 +100,7 @@ stream_new (dets, limit, get_func, put_func)
  * returned for handling by the calling function.
  **/
 snv_pointer
-stream_delete (stream)
-     STREAM *stream;
+stream_delete (STREAM *stream)
 {
   snv_pointer dets = stream->stream;
   snv_delete (stream);
@@ -125,8 +120,7 @@ stream_delete (stream)
  * when it was originally created.
  **/
 snv_pointer
-stream_details (stream)
-     STREAM *stream;
+stream_details (STREAM *stream)
 {
   return stream ? stream->stream : NULL;
 }
@@ -143,13 +137,11 @@ stream_details (stream)
  * If @stream is full, return 1.  Otherwise, if any other error occurs,
  * that error code is returned unchanged.  This is of course dependant
  * on what the handler function uses to indicate an error.  If the stream
- * is not full and the stream's writing function suceeds, 1 (the number of
+ * is not full and the stream's writing function succeeds, 1 (the number of
  * characters emitted!) is returned.
  **/
 int
-stream_put (ch, stream)
-     int ch;
-     STREAM *stream;
+stream_put (int ch, STREAM *stream)
 {
   int ch_or_errorcode;
 
@@ -165,6 +157,46 @@ stream_put (ch, stream)
   return (ch_or_errorcode < 0) ? ch_or_errorcode : 1;
 }
 
+/**
+ * stream_puts:
+ * @s: A string to be placed in @stream.
+ * @stream: The stream to be written to.
+ *
+ * This function will @ch in @stream if that stream's output limit will
+ * not be exceeded.
+ *
+ * Return value:
+ * If any other error occurs, that error code is returned unchanged.
+ * This is of course dependant on what the handler function uses to
+ * indicate an error.  If the stream becomes full, the remaining
+ * characters are not printed.  If the stream's writing function
+ * always succeeds, the number of characters emitted or skipped is
+ * returned.
+ **/
+int
+stream_puts (char *s, STREAM *stream)
+{
+  int ch_or_errorcode;
+  int num;
+
+  if (!stream)
+    return -1;
+
+  for (num = 0; *s; num++, s++)
+    {
+      if (stream->limit < 1)
+        return num + strlen (s);
+
+      stream->limit -= 1;
+      ch_or_errorcode = (*stream->put_func) (*s, stream);
+
+      if (ch_or_errorcode < 0)
+	return ch_or_errorcode;
+    }
+
+  return num;
+}
+
 /**
  * stream_get:
  * @stream: The stream to be read from.
@@ -177,8 +209,7 @@ stream_put (ch, stream)
  * an int) is returned.
  **/
 int
-stream_get (stream)
-     STREAM *stream;
+stream_get (STREAM *stream)
 {
   return (*stream->get_func) (stream);
 }
